@@ -111,6 +111,10 @@ CREATE TABLE `experiment` (
   `expname` text,
   `expdescr` text,
   `addeddate` datetime DEFAULT NULL,
+  `publicdate` text DEFAULT NULL,
+  `submissiondate` text DEFAULT NULL,
+  `lastupdatedate` text DEFAULT NULL,
+  `pubmedid` bigint(20) DEFAULT NULL,
   `tag` text DEFAULT NULL,
   `esetFileSize` bigint(20) DEFAULT NULL,
   `date_loaded` DATETIME NULL,
